@@ -6,10 +6,14 @@
 ( cd usr/X11R6/share/blackbox/nls ; ln -sf de_DE de )
 ( cd usr/X11R6/share/blackbox/nls ; rm -rf en )
 ( cd usr/X11R6/share/blackbox/nls ; ln -sf C en )
+( cd usr/X11R6/share/blackbox/nls ; rm -rf en_GB )
+( cd usr/X11R6/share/blackbox/nls ; ln -sf C en_GB )
 ( cd usr/X11R6/share/blackbox/nls ; rm -rf en_US )
 ( cd usr/X11R6/share/blackbox/nls ; ln -sf C en_US )
 ( cd usr/X11R6/share/blackbox/nls ; rm -rf es )
 ( cd usr/X11R6/share/blackbox/nls ; ln -sf es_ES es )
+( cd usr/X11R6/share/blackbox/nls ; rm -rf es_MX )
+( cd usr/X11R6/share/blackbox/nls ; ln -sf es_ES es_MX )
 ( cd usr/X11R6/share/blackbox/nls ; rm -rf fr )
 ( cd usr/X11R6/share/blackbox/nls ; ln -sf fr_FR fr )
 ( cd usr/X11R6/share/blackbox/nls ; rm -rf it )
